<?php

namespace Drupal\google_calendar\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Logger\LoggerChannelFactory;
use Drupal\google_calendar\GoogleCalendarImportCalendar;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Class GoogleCalendarImportCalendarController.
 *
 * @package \Drupal\google_calendar
 */
class GoogleCalendarImportCalendarController extends ControllerBase {

  /**
   * @var \Drupal\Core\Logger\LoggerChannelFactory The logger to use for status messages.
   */
  protected $logger;

  /**
   * \Drupal\google_calendar\GoogleCalendarImport definition.
   *
   * @var \Drupal\google_calendar\GoogleCalendarImportCalendar
   */
  protected $calendarImport;

  /**
   * Importer for Calendars.
   *
   * @param GoogleCalendarImportCalendar $google_calendar_import
   *   Constructs a new GoogleCalendarImportEventsController object.
   * @param \Drupal\Core\Logger\LoggerChannelFactory $loggerFactory
   *   Factory for logger notices.
   */
  public function __construct(GoogleCalendarImportCalendar $google_calendar_import, LoggerChannelFactory $loggerFactory) {
    $this->calendarImport = $google_calendar_import;
    $this->logger = $loggerFactory->get('google_calendar');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('google_calendar.import_calendar'),
      $container->get('logger.factory')
    );
  }

  /**
   * Import a Calendar from Google as a new Entity.
   *
   * @param string $calendar_id
   *   Google ID of the calendar to import.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The next page.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function importCalendar(string $calendar_id): RedirectResponse {

    $google_calendar = $this->calendarImport->import($calendar_id);

    if ($google_calendar) {
      $this->output()->writeln($this->t('The <strong>@calendar</strong> Calendar has been imported successfully!', [
        '@calendar' => $google_calendar->getName()
      ]));
    }
    else {
      $this->output()->writeln($this->t('The Calendar has not been imported successfully!'));
    }
    return $this->redirect('entity.google_calendar.collection');
  }

}
