<?php

namespace Drupal\google_calendar\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\google_calendar\Entity\GoogleCalendar;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\google_calendar\GoogleCalendarImport;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Class ImportCalendarForm.
 *
 * @package Drupal\google_calendar\Form
 */
class ImportForm extends FormBase {

  /**
   * Google Calendar Importer object.
   *
   * @var \Drupal\google_calendar\GoogleCalendarImport
   */
  protected $calendarService;

  /**
   * The Entity Type Manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * ImportForm constructor.
   *
   * @param \Drupal\google_calendar\GoogleCalendarImport $google_calendar_service
   *   Importer object.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity manager object for google calendars.
   */
  public function __construct(GoogleCalendarImport $google_calendar_service, EntityTypeManagerInterface $entityTypeManager) {
    $this->calendarService = $google_calendar_service;
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('google_calendar.import'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'google_calendar_import_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => t('Synchronize Events'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  public static function handleBatchProcess($calendar, $total, &$context){
    $name = $calendar->label();
    $context['message'] = "Imported Calendar: $name";
    \Drupal::service('google_calendar.import')->import($calendar);
  }

  public static function batchProcessCallback($success, $results, $operations){
    if ($success) {
      \Drupal::messenger()->addMessage(t('Finished importing calendar events'));
    }
    else {
      \Drupal::messenger()->addMessage(t('Finished with an error.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $query = $this->entityTypeManager
      ->getStorage('google_calendar')
      ->getQuery()
      ->condition('status', 1);

    $calendarIds = $query->execute();

    $foundCalendars = GoogleCalendar::loadMultiple($calendarIds);
    $operations = [];
    $total = count($foundCalendars);
    foreach ($foundCalendars as $calendar) {
      $operations[] = [
        '\Drupal\google_calendar\Form\ImportForm::handleBatchProcess', [$calendar, $total]
      ];
    }

    $batch = [
      'title' => t('Importing Calendars'),
      'operations' => $operations,
      'finished' => '\Drupal\google_calendar\Form\ImportForm::batchProcessCallback',
    ];

    return batch_set($batch);
  }
}
